==> jc-1.4.0.tar.gz: java/io/FilterWriter.h <==
// public abstract class java.io.FilterWriter

// class file dependencies
// @dep_class a4c6ebbb4edda7cb java_io_FilterWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_Writer

#include "java/io/Writer.h"

#ifndef _JC_java_io_FilterWriter_H_
#define _JC_java_io_FilterWriter_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_FilterWriter$sub_refs	_jc_java_io_FilterWriter$sub_refs;
typedef struct _jc_java_io_FilterWriter$sub_nonrefs	_jc_java_io_FilterWriter$sub_nonrefs;
typedef struct _jc_java_io_FilterWriter$refs	_jc_java_io_FilterWriter$refs;
typedef struct _jc_java_io_FilterWriter$nonrefs	_jc_java_io_FilterWriter$nonrefs;
typedef struct _jc_java_io_FilterWriter$object	_jc_java_io_FilterWriter$object;

typedef const struct _jc_java_io_FilterWriter$vmethods	_jc_java_io_FilterWriter$vmethods;
typedef const struct _jc_java_io_FilterWriter$vtable	_jc_java_io_FilterWriter$vtable;
typedef const struct _jc_java_io_FilterWriter$vtype	_jc_java_io_FilterWriter$vtype;

// Constructors
extern void _jc_java_io_FilterWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_java_io_Writer$object *);

// Virtual methods
extern void _jc_java_io_FilterWriter$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_FilterWriter$object *);
extern void _jc_java_io_FilterWriter$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_FilterWriter$object *);
extern void _jc_java_io_FilterWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_FilterWriter$object *, jint);
extern void _jc_java_io_FilterWriter$method$write$4cff879bd9d86786(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_java_lang_String$object *, jint, jint);
extern void _jc_java_io_FilterWriter$method$write$dc4877c8c0adbc0a(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_char_array *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_java_io_FilterWriter$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_FilterWriter$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_FilterWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_FilterWriter$method_info$write$4cff879bd9d86786;
extern _jc_method _jc_java_io_FilterWriter$method_info$write$dc4877c8c0adbc0a;

// Virtual methods structure
struct _jc_java_io_FilterWriter$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_FilterWriter$object *);
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_FilterWriter$object *);
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_FilterWriter$object *, jint);
	void	(*write$4cff879bd9d86786)(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_java_lang_String$object *, jint, jint);
	void	(*write$dc4877c8c0adbc0a)(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_char_array *, jint, jint);
};

// Vtable
struct _jc_java_io_FilterWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_FilterWriter$vmethods	java_io_FilterWriter;
};

// Vtype
struct _jc_java_io_FilterWriter$vtype {
	_jc_type			type;
	_jc_java_io_FilterWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FilterWriter$sub_refs {
	struct _jc_java_io_Writer$object	*out;
};

// Reference instance fields (object)
struct _jc_java_io_FilterWriter$refs {
    _jc_java_io_FilterWriter$sub_refs	java_io_FilterWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FilterWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FilterWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_FilterWriter$sub_nonrefs	java_io_FilterWriter;
};

// Object instance structure
struct _jc_java_io_FilterWriter$object {
	_jc_java_io_FilterWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FilterWriter$vtype	*vtype;
	_jc_java_io_FilterWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FilterWriter$vtype _jc_java_io_FilterWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FilterWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FilterWriter$class_object;

#endif	/* _JC_java_io_FilterWriter_H_ */

==> jc-1.4.6.tar.gz: java/io/FilterWriter.h <==
// public abstract class java.io.FilterWriter

// class file dependencies
// @dep_class a4c6ebbb4edda7cb java_io_FilterWriter
// @dep_class 4897ee169f60a14f java_io_Writer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_Writer

#include "java/io/Writer.h"

#ifndef _JC_java_io_FilterWriter_H_
#define _JC_java_io_FilterWriter_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_io_FilterWriter$sub_refs	_jc_java_io_FilterWriter$sub_refs;
typedef struct _jc_java_io_FilterWriter$sub_nonrefs	_jc_java_io_FilterWriter$sub_nonrefs;
typedef struct _jc_java_io_FilterWriter$refs	_jc_java_io_FilterWriter$refs;
typedef struct _jc_java_io_FilterWriter$nonrefs	_jc_java_io_FilterWriter$nonrefs;
typedef struct _jc_java_io_FilterWriter$object	_jc_java_io_FilterWriter$object;

typedef const struct _jc_java_io_FilterWriter$vmethods	_jc_java_io_FilterWriter$vmethods;
typedef const struct _jc_java_io_FilterWriter$vtable	_jc_java_io_FilterWriter$vtable;
typedef const struct _jc_java_io_FilterWriter$vtype	_jc_java_io_FilterWriter$vtype;

// Constructors
extern void _jc_java_io_FilterWriter$method$_init$514f7e161933236e(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_java_io_Writer$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_io_FilterWriter$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_io_FilterWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterWriter$method$flush$9dedb7d85e88cf56(_jc_env *, struct _jc_java_io_FilterWriter$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterWriter$method$write$6377ac6964854eb2(_jc_env *, struct _jc_java_io_FilterWriter$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterWriter$method$write$4cff879bd9d86786(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_FilterWriter$method$write$dc4877c8c0adbc0a(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_FilterWriter$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_io_FilterWriter$method_info$flush$9dedb7d85e88cf56;
extern _jc_method _jc_java_io_FilterWriter$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_java_io_FilterWriter$method_info$write$4cff879bd9d86786;
extern _jc_method _jc_java_io_FilterWriter$method_info$write$dc4877c8c0adbc0a;

// Virtual methods structure
struct _jc_java_io_FilterWriter$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_io_FilterWriter$object *) _JC_JCNI_ATTR;
	void	(*flush$9dedb7d85e88cf56)(_jc_env *, struct _jc_java_io_FilterWriter$object *) _JC_JCNI_ATTR;
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_java_io_FilterWriter$object *, jint) _JC_JCNI_ATTR;
	void	(*write$4cff879bd9d86786)(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;
	void	(*write$dc4877c8c0adbc0a)(_jc_env *, struct _jc_java_io_FilterWriter$object *, struct _jc_char_array *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_FilterWriter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_Writer$vmethods	java_io_Writer;
	_jc_java_io_FilterWriter$vmethods	java_io_FilterWriter;
};

// Vtype
struct _jc_java_io_FilterWriter$vtype {
	_jc_type			type;
	_jc_java_io_FilterWriter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_FilterWriter$sub_refs {
	struct _jc_java_io_Writer$object	*out;
};

// Reference instance fields (object)
struct _jc_java_io_FilterWriter$refs {
    _jc_java_io_FilterWriter$sub_refs	java_io_FilterWriter;
    _jc_java_io_Writer$sub_refs	java_io_Writer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_FilterWriter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_FilterWriter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_Writer$sub_nonrefs	java_io_Writer;
    _jc_java_io_FilterWriter$sub_nonrefs	java_io_FilterWriter;
};

// Object instance structure
struct _jc_java_io_FilterWriter$object {
	_jc_java_io_FilterWriter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_FilterWriter$vtype	*vtype;
	_jc_java_io_FilterWriter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_FilterWriter$vtype _jc_java_io_FilterWriter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_FilterWriter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_FilterWriter$class_object;

#endif	/* _JC_java_io_FilterWriter_H_ */
